@@ -59,6 +59,7 @@ Version 0.01_10
 =cut
 
 our $VERSION = '0.01_10';
+$VERSION = eval $VERSION;
 
 
 =head1 SYNOPSIS
@@ -175,8 +176,7 @@ sub new {
             OpenGL::glutInitDisplayMode( OpenGL::GLUT_RGBA() | OpenGL::GLUT_DOUBLE() | OpenGL::GLUT_DEPTH() );
             if ( not OpenGL::glutGet( OpenGL::GLUT_DISPLAY_MODE_POSSIBLE() ) )
             {
-               warn "glutInitDisplayMode(GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH) not possible, exiting quietly";
-               exit 0;
+               die "display mode not possible";
             }
          }
       }
